MongoMotorModel
===============

Django like models and validation for mongodb and tornado.

Usage
-----

*TODO*

License
-------

Copytight (c) 2016 sedrubal

`MIT <https://opensource.org/licenses/MIT>`__
